@@ -11,8 +11,8 @@ animations = {
       fps = 10
    }
 }
-add_walking_animations(animations, "walk", dirname, "walk", {16, 31}, 10)
-add_walking_animations(animations, "walkload", dirname, "walkload", {13, 29}, 10)
+add_directional_animation(animations, "walk", dirname, "walk", {16, 31}, 10)
+add_directional_animation(animations, "walkload", dirname, "walkload", {13, 29}, 10)
 
 
 tribes:new_worker_type {
@@ -33,9 +33,9 @@ tribes:new_worker_type {
       harvest = {
          "findobject=attrib:tree radius:10",
          "walk=object",
-         "playsound=sound/atlanteans/saw sawing 230",
-         "animate=sawing 10000",
-         "playsound=sound/woodcutting tree-falling 130",
+         "playsound=sound/atlanteans/saw/sawing 230",
+         "animate=sawing 20000",
+         "playsound=sound/woodcutting/tree_falling 130",
          "callobject=fall",
          "animate=idle 2000",
          "createware=log",
