@@ -6,8 +6,8 @@ animations = {
       hotspot = { 4, 26 },
    }
 }
-add_walking_animations(animations, "walk", dirname, "walk", {6, 26}, 10)
-add_walking_animations(animations, "walkload", dirname, "walkload", {6, 26}, 10)
+add_directional_animation(animations, "walk", dirname, "walk", {6, 26}, 10)
+add_directional_animation(animations, "walkload", dirname, "walkload", {6, 26}, 10)
 
 
 tribes:new_worker_type {
