@@ -4,15 +4,14 @@ animations = {
    idle = {
       pictures = path.list_files(dirname .. "idle_??.png"),
       sound_effect = {
-         directory = "sound/farm",
-         name = "sheep",
+         path = "sound/farm/sheep",
       },
       hotspot = { 8, 16 },
       fps = 20,
    },
 }
 
-add_walking_animations(animations, "walk", dirname, "walk", {15, 25}, 20)
+add_directional_animation(animations, "walk", dirname, "walk", {15, 25}, 20)
 
 world:new_critter_type{
    name = "sheep",
