@@ -29,12 +29,16 @@ world:new_immovable_type{
          "grow=alder_summer_pole",
       },
    },
-   animations = {
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "sapling/idle_?.png"),
-         hotspot = { 5, 12 },
+         directory = dirname,
+         basename = "sapling",
          fps = 8,
-      },
+         frames = 4,
+         rows = 2,
+         columns = 2,
+         hotspot = { 6, 13 }
+      }
    },
 }
 
@@ -52,12 +56,16 @@ world:new_immovable_type{
          "grow=alder_summer_mature",
       },
    },
-   animations = {
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "pole/idle_?.png"),
-         hotspot = { 12, 28 },
+         directory = dirname,
+         basename = "pole",
          fps = 8,
-      },
+         frames = 4,
+         rows = 2,
+         columns = 2,
+         hotspot = { 13, 29 }
+      }
    },
 }
 
@@ -75,12 +83,16 @@ world:new_immovable_type{
          "grow=alder_summer_old",
       },
    },
-   animations = {
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "mature/idle_?.png"),
-         hotspot = { 18, 48 },
+         directory = dirname,
+         basename = "mature",
          fps = 8,
-      },
+         frames = 4,
+         rows = 2,
+         columns = 2,
+         hotspot = { 19, 49 }
+      }
    },
 }
 
@@ -88,6 +100,7 @@ world:new_immovable_type{
    name = "alder_summer_old",
    descname = _ "Alder (Old)",
    species = _ "Alder",
+   icon = dirname .. "menu.png",
    editor_category = "trees_deciduous",
    size = "small",
    attributes = { "tree" },
@@ -96,21 +109,24 @@ world:new_immovable_type{
       program = {
          "animate=idle 1550000",
          "transform=deadtree4 5",
-         "seed=alder_summer_sapling",
+         "seed=alder_summer_sapling 180",
       },
       fall = {
          "remove=",
       },
    },
-   animations = {
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "old/idle_?.png"),
-         hotspot = { 23, 59 },
+         directory = dirname,
+         basename = "old",
          fps = 10,
+         frames = 4,
+         rows = 2,
+         columns = 2,
+         hotspot = { 24, 60 },
          sound_effect = {
-            directory = "sound/animals",
-            name = "bird4",
-         },
-      },
+            path = "sound/animals/bird4",
+         }
+      }
    },
 }
